BioSimulators-COPASI documentation — BioSimulators-COPASI 0.1.33 documentation

# BioSimulators-COPASI documentation

BioSimulators-COPASI provides a BioSimulators-compliant command-line interface to the COPASI biological simulation tool. A Docker image for this package is also available.

This command-line interface and Docker image enable users to use COPASI to execute COMBINE/OMEX archives that describe one or more simulation experiments (in SED-ML format) of one or more models (in SBML format).

A list of the algorithms and algorithm parameters supported by COPASI is available at BioSimulators.

A simple web application and web service for using COPASI to execute COMBINE/OMEX archives is also available at runBioSimulations.

## Contents

- Installation instructions
  - Command-line program
  - Docker image with a command-line entrypoint
- Tutorial
  - Creating COMBINE/OMEX archives and encoding simulation experiments into SED-ML
  - Command-line program for executing COMBINE/OMEX archives
  - Docker image with a command-line entrypoint
  - Command-line program for correcting COMBINE/OMEX archives created by COPASI
- API documentation
  - Submodules
  - biosimulators_copasi.core module
  - biosimulators_copasi.data_model module
  - biosimulators_copasi.utils module
- About BioSimulators-COPASI
  - License
  - Development team
  - Questions and comments
- Index